@@ -612,7 +612,7 @@ impl<'a, S: Entry, C: CrudOperation> Action<'a, S, C, EntryTarget> {
 impl<'a, S: IndexEntry, C: CrudOperation> Action<'a, S, C, EntryTarget> {
 	/// Sets the [`Entry`] and [`Key`] that this [`Action`] will act over.
 	pub fn set_entry(&mut self, entity: &'a S) -> &mut Self {
-		self.set_key(&entity.key()).set_data(entity)
+		self.set_key(entity.key()).set_data(entity)
 	}
 }
 
@@ -760,268 +760,3 @@ impl<'a, S: Entry> DeleteTableAction<'a, S> {
 		self.inner.delete_table(gateway)
 	}
 }
-
-#[cfg(all(test, feature = "memory", feature = "metadata"))]
-mod tests {
-	use serde::{Deserialize, Serialize};
-
-	use super::{
-		error::ActionError, Action, ActionKind, CreateEntryAction, CreateOperation,
-		CreateTableAction, DeleteEntryAction, DeleteTableAction, EntryTarget, ReadEntryAction,
-		ReadOperation, ReadTableAction, TableTarget, UpdateEntryAction,
-	};
-	use crate::{action::TargetKind, backend::MemoryBackend, IndexEntry, Starchart};
-
-	#[derive(
-		Debug, Default, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash, Serialize, Deserialize,
-	)]
-	struct Settings {
-		id: u64,
-		option: bool,
-		value: u8,
-	}
-
-	impl IndexEntry for Settings {
-		type Key = u64;
-
-		fn key(&self) -> Self::Key {
-			self.id
-		}
-	}
-
-	async fn setup_gateway() -> Starchart<MemoryBackend> {
-		let backend = MemoryBackend::new();
-		Starchart::new(backend).await.unwrap()
-	}
-
-	async fn setup_table(gateway: &Starchart<MemoryBackend>) {
-		let mut action: CreateTableAction<Settings> = Action::new();
-
-		action.set_table("table");
-
-		action.run_create_table(gateway).await.unwrap();
-	}
-
-	#[test]
-	fn new_kind_and_target() {
-		let action: Action<Settings, ReadOperation, EntryTarget> = Action::new();
-
-		assert_eq!(action.kind(), ActionKind::Read);
-		assert_eq!(action.target(), TargetKind::Entry);
-	}
-
-	#[test]
-	fn set_methods() {
-		let def = Settings::default();
-		let mut action: Action<Settings, ReadOperation, EntryTarget> = Action::new();
-		action.set_entry(&def);
-
-		assert_eq!(action.data(), Some(&Settings::default()));
-		assert_eq!(action.key(), Some("0"));
-
-		let mut action = action.set_key(&"1").clone();
-		assert_eq!(action.key(), Some("1"));
-
-		let action = action.set_data(&Settings {
-			id: 7,
-			option: false,
-			value: 79,
-		});
-
-		assert_eq!(
-			action.data(),
-			Some(&Settings {
-				id: 7,
-				option: false,
-				value: 79
-			})
-		);
-	}
-
-	#[test]
-	fn default() {
-		let default = Action::<Settings, ReadOperation, EntryTarget>::default();
-
-		assert!(default.data().is_none());
-		assert!(default.key().is_none());
-	}
-
-	#[test]
-	fn validation_methods() {
-		let def = Settings::default();
-		let mut action: Action<Settings, ReadOperation, EntryTarget> = Action::default();
-
-		assert!(action.validate_key().is_err());
-		action.set_key(&"foo");
-		assert!(action.validate_key().is_ok());
-
-		assert!(action.validate_table().is_err());
-		action.set_table("test");
-		assert!(action.validate_table().is_ok());
-
-		assert!(action.validate_data().is_err());
-		action.set_data(&def);
-		assert!(action.validate_data().is_ok());
-
-		action.set_key(&"__metadata__");
-		assert!(action.validate_key().is_err());
-
-		action.set_table("__metadata__");
-		assert!(action.validate_table().is_err());
-	}
-
-	#[tokio::test]
-	#[cfg_attr(miri, ignore)]
-	async fn basic_run() -> Result<(), ActionError> {
-		let gateway = setup_gateway().await;
-		let mut action: Action<Settings, CreateOperation, TableTarget> = Action::new();
-
-		action.set_table("table");
-
-		action.run_create_table(&gateway).await?;
-
-		for i in 0..3 {
-			let settings = Settings {
-				id: i,
-				option: false,
-				value: 8,
-			};
-			let mut action: CreateEntryAction<Settings> = Action::new();
-
-			action.set_table("table").set_entry(&settings);
-
-			action.run_create_entry(&gateway).await?;
-		}
-
-		let mut read_table: ReadTableAction<Settings> = Action::new();
-
-		read_table.set_table("table");
-
-		let mut values = read_table
-			.run_read_table::<MemoryBackend, Vec<_>>(&gateway)
-			.await?;
-		let mut expected = vec![
-			Settings {
-				id: 0,
-				option: false,
-				value: 8,
-			},
-			Settings {
-				id: 1,
-				option: false,
-				value: 8,
-			},
-			Settings {
-				id: 2,
-				option: false,
-				value: 8,
-			},
-		];
-
-		values.sort();
-		expected.sort();
-
-		assert_eq!(values, expected);
-
-		Ok(())
-	}
-
-	#[tokio::test]
-	#[cfg_attr(miri, ignore)]
-	async fn duplicate_creates() -> Result<(), ActionError> {
-		let def = Settings::default();
-		let gateway = setup_gateway().await;
-		setup_table(&gateway).await;
-
-		let mut create_action: CreateEntryAction<Settings> = Action::new();
-
-		create_action.set_table("table").set_entry(&def);
-
-		let double_create = create_action.clone();
-
-		assert!(create_action.run_create_entry(&gateway).await.is_ok());
-
-		assert!(double_create.run_create_entry(&gateway).await.is_ok());
-
-		Ok(())
-	}
-
-	#[tokio::test]
-	#[cfg_attr(miri, ignore)]
-	async fn read_and_update() -> Result<(), ActionError> {
-		let gateway = setup_gateway().await;
-		setup_table(&gateway).await;
-		{
-			let def = Settings::default();
-			let mut create_action: CreateEntryAction<Settings> = Action::new();
-			create_action.set_table("table").set_entry(&def);
-			create_action.run_create_entry(&gateway).await?;
-		}
-
-		let mut read_action: ReadEntryAction<Settings> = Action::new();
-
-		read_action.set_key(&0_u32).set_table("table");
-
-		let reread_action = read_action.clone();
-
-		let value = read_action.run_read_entry(&gateway).await?;
-		assert_eq!(value, Some(Settings::default()));
-
-		let new_settings = Settings {
-			id: 0,
-			option: true,
-			value: 42,
-		};
-
-		let mut update_action: UpdateEntryAction<Settings> = Action::new();
-
-		update_action
-			.set_table("table")
-			.set_key(&0_u32)
-			.set_data(&new_settings);
-
-		update_action.run_update_entry(&gateway).await?;
-
-		assert_eq!(
-			reread_action.run_read_entry(&gateway).await?,
-			Some(new_settings)
-		);
-
-		Ok(())
-	}
-
-	#[tokio::test]
-	#[cfg_attr(miri, ignore)]
-	async fn deletes() -> Result<(), ActionError> {
-		let gateway = setup_gateway().await;
-		setup_table(&gateway).await;
-
-		{
-			let def = Settings::default();
-			let mut create_action = CreateEntryAction::<Settings>::new();
-
-			create_action.set_table("table").set_entry(&def);
-
-			create_action.run_create_entry(&gateway).await?;
-		}
-
-		let mut delete_action: DeleteEntryAction<Settings> = Action::new();
-		delete_action.set_table("table").set_key(&0_u32);
-		assert!(delete_action.run_delete_entry(&gateway).await?);
-		let mut read_action: ReadEntryAction<Settings> = Action::new();
-		read_action.set_table("table").set_key(&0_u32);
-		assert_eq!(read_action.run_read_entry(&gateway).await?, None);
-
-		let mut delete_table_action: DeleteTableAction<Settings> = Action::new();
-		delete_table_action.set_table("table");
-		assert!(delete_table_action.run_delete_table(&gateway).await?);
-		let mut read_table: ReadTableAction<Settings> = Action::new();
-		read_table.set_table("table");
-
-		let res: Result<Vec<Settings>, ActionError> = read_table.run_read_table(&gateway).await;
-
-		assert!(res.is_err());
-
-		Ok(())
-	}
-}
